def quicktext():
    return 'Hello, welcome to QuickSample package.'


def anotherfunction():
  return "Hello, this is sometext from another function"
